@@ -1,4 +1,6 @@
-print('importing hello world functios')
+print('importing hello world functions')
 
 from .hello_world import say_hello_world
-from .hello_world_2 import say_hello_again
\ No newline at end of file
+from .hello_world_2 import say_hello_again
+
+print('Imported hello world functions')
\ No newline at end of file
